# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.0-rc19
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr, conlist
from polyaxon_sdk.models.v1_optimization_metric import V1OptimizationMetric
from polyaxon_sdk.models.v1_tuner import V1Tuner

class V1Bayes(BaseModel):
    """
    V1Bayes
    """
    kind: Optional[StrictStr] = 'bayes'
    params: Optional[Dict[str, Dict[str, Any]]] = None
    num_initial_runs: Optional[StrictInt] = Field(None, alias="numInitialRuns")
    max_iterations: Optional[StrictInt] = Field(None, alias="maxIterations")
    utility_function: Optional[Dict[str, Any]] = Field(None, alias="utilityFunction")
    metric: Optional[V1OptimizationMetric] = None
    seed: Optional[StrictInt] = None
    concurrency: Optional[StrictInt] = None
    tuner: Optional[V1Tuner] = None
    early_stopping: Optional[conlist(Dict[str, Any])] = Field(None, alias="earlyStopping")
    __properties = ["kind", "params", "numInitialRuns", "maxIterations", "utilityFunction", "metric", "seed", "concurrency", "tuner", "earlyStopping"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1Bayes:
        """Create an instance of V1Bayes from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of metric
        if self.metric:
            _dict['metric'] = self.metric.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tuner
        if self.tuner:
            _dict['tuner'] = self.tuner.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1Bayes:
        """Create an instance of V1Bayes from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1Bayes.parse_obj(obj)

        _obj = V1Bayes.parse_obj({
            "kind": obj.get("kind") if obj.get("kind") is not None else 'bayes',
            "params": obj.get("params"),
            "num_initial_runs": obj.get("numInitialRuns"),
            "max_iterations": obj.get("maxIterations"),
            "utility_function": obj.get("utilityFunction"),
            "metric": V1OptimizationMetric.from_dict(obj.get("metric")) if obj.get("metric") is not None else None,
            "seed": obj.get("seed"),
            "concurrency": obj.get("concurrency"),
            "tuner": V1Tuner.from_dict(obj.get("tuner")) if obj.get("tuner") is not None else None,
            "early_stopping": obj.get("earlyStopping")
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.0-rc19
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field
from polyaxon_sdk.models.v1_bucket_connection import V1BucketConnection
from polyaxon_sdk.models.v1_claim_connection import V1ClaimConnection
from polyaxon_sdk.models.v1_git_connection import V1GitConnection
from polyaxon_sdk.models.v1_host_connection import V1HostConnection
from polyaxon_sdk.models.v1_host_path_connection import V1HostPathConnection

class V1ConnectionSchema(BaseModel):
    """
    V1ConnectionSchema
    """
    bucket_connection: Optional[V1BucketConnection] = Field(None, alias="bucketConnection")
    host_path_connection: Optional[V1HostPathConnection] = Field(None, alias="hostPathConnection")
    claim_connection: Optional[V1ClaimConnection] = Field(None, alias="claimConnection")
    host_connection: Optional[V1HostConnection] = Field(None, alias="hostConnection")
    git_connection: Optional[V1GitConnection] = Field(None, alias="gitConnection")
    __properties = ["bucketConnection", "hostPathConnection", "claimConnection", "hostConnection", "gitConnection"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1ConnectionSchema:
        """Create an instance of V1ConnectionSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of bucket_connection
        if self.bucket_connection:
            _dict['bucketConnection'] = self.bucket_connection.to_dict()
        # override the default output from pydantic by calling `to_dict()` of host_path_connection
        if self.host_path_connection:
            _dict['hostPathConnection'] = self.host_path_connection.to_dict()
        # override the default output from pydantic by calling `to_dict()` of claim_connection
        if self.claim_connection:
            _dict['claimConnection'] = self.claim_connection.to_dict()
        # override the default output from pydantic by calling `to_dict()` of host_connection
        if self.host_connection:
            _dict['hostConnection'] = self.host_connection.to_dict()
        # override the default output from pydantic by calling `to_dict()` of git_connection
        if self.git_connection:
            _dict['gitConnection'] = self.git_connection.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1ConnectionSchema:
        """Create an instance of V1ConnectionSchema from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1ConnectionSchema.parse_obj(obj)

        _obj = V1ConnectionSchema.parse_obj({
            "bucket_connection": V1BucketConnection.from_dict(obj.get("bucketConnection")) if obj.get("bucketConnection") is not None else None,
            "host_path_connection": V1HostPathConnection.from_dict(obj.get("hostPathConnection")) if obj.get("hostPathConnection") is not None else None,
            "claim_connection": V1ClaimConnection.from_dict(obj.get("claimConnection")) if obj.get("claimConnection") is not None else None,
            "host_connection": V1HostConnection.from_dict(obj.get("hostConnection")) if obj.get("hostConnection") is not None else None,
            "git_connection": V1GitConnection.from_dict(obj.get("gitConnection")) if obj.get("gitConnection") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.0-rc19
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist
from polyaxon_sdk.models.spark_deploy_mode import SparkDeployMode
from polyaxon_sdk.models.v1_spark_replica import V1SparkReplica
from polyaxon_sdk.models.v1_spark_type import V1SparkType

class V1Spark(BaseModel):
    """
    V1Spark
    """
    kind: Optional[StrictStr] = 'spark'
    connections: Optional[conlist(StrictStr)] = None
    volumes: Optional[conlist(Dict[str, Any])] = Field(None, description="Volumes is a list of volumes that can be mounted.")
    type: Optional[V1SparkType] = None
    spark_version: Optional[StrictStr] = Field(None, alias="sparkVersion", description="Spark version is the version of Spark the application uses.")
    python_version: Optional[StrictStr] = Field(None, alias="pythonVersion", description="Spark version is the version of Spark the application uses.")
    deploy_mode: Optional[SparkDeployMode] = Field(None, alias="deployMode")
    main_class: Optional[StrictStr] = Field(None, alias="mainClass", description="MainClass is the fully-qualified main class of the Spark application. This only applies to Java/Scala Spark applications.")
    main_application_file: Optional[StrictStr] = Field(None, alias="mainApplicationFile", description="MainFile is the path to a bundled JAR, Python, or R file of the application.")
    arguments: Optional[conlist(StrictStr)] = Field(None, description="Arguments is a list of arguments to be passed to the application.")
    hadoop_conf: Optional[Dict[str, StrictStr]] = Field(None, alias="hadoopConf", description="HadoopConf carries user-specified Hadoop configuration properties as they would use the  the \"--conf\" option in spark-submit.  The SparkApplication controller automatically adds prefix \"spark.hadoop.\" to Hadoop configuration properties.")
    spark_conf: Optional[Dict[str, StrictStr]] = Field(None, alias="sparkConf", description="HadoopConf carries user-specified Hadoop configuration properties as they would use the  the \"--conf\" option in spark-submit.  The SparkApplication controller automatically adds prefix \"spark.hadoop.\" to Hadoop configuration properties.")
    spark_config_map: Optional[StrictStr] = Field(None, alias="sparkConfigMap", description="SparkConfigMap carries the name of the ConfigMap containing Spark configuration files such as log4j.properties. The controller will add environment variable SPARK_CONF_DIR to the path where the ConfigMap is mounted to.")
    hadoop_config_map: Optional[StrictStr] = Field(None, alias="hadoopConfigMap", description="HadoopConfigMap carries the name of the ConfigMap containing Hadoop configuration files such as core-site.xml. The controller will add environment variable HADOOP_CONF_DIR to the path where the ConfigMap is mounted to.")
    executor: Optional[V1SparkReplica] = None
    driver: Optional[V1SparkReplica] = None
    __properties = ["kind", "connections", "volumes", "type", "sparkVersion", "pythonVersion", "deployMode", "mainClass", "mainApplicationFile", "arguments", "hadoopConf", "sparkConf", "sparkConfigMap", "hadoopConfigMap", "executor", "driver"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1Spark:
        """Create an instance of V1Spark from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of executor
        if self.executor:
            _dict['executor'] = self.executor.to_dict()
        # override the default output from pydantic by calling `to_dict()` of driver
        if self.driver:
            _dict['driver'] = self.driver.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1Spark:
        """Create an instance of V1Spark from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1Spark.parse_obj(obj)

        _obj = V1Spark.parse_obj({
            "kind": obj.get("kind") if obj.get("kind") is not None else 'spark',
            "connections": obj.get("connections"),
            "volumes": obj.get("volumes"),
            "type": obj.get("type"),
            "spark_version": obj.get("sparkVersion"),
            "python_version": obj.get("pythonVersion"),
            "deploy_mode": obj.get("deployMode"),
            "main_class": obj.get("mainClass"),
            "main_application_file": obj.get("mainApplicationFile"),
            "arguments": obj.get("arguments"),
            "hadoop_conf": obj.get("hadoopConf"),
            "spark_conf": obj.get("sparkConf"),
            "spark_config_map": obj.get("sparkConfigMap"),
            "hadoop_config_map": obj.get("hadoopConfigMap"),
            "executor": V1SparkReplica.from_dict(obj.get("executor")) if obj.get("executor") is not None else None,
            "driver": V1SparkReplica.from_dict(obj.get("driver")) if obj.get("driver") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.0-rc19
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel
from polyaxon_sdk.models.v1_diff_stopping_policy import V1DiffStoppingPolicy
from polyaxon_sdk.models.v1_failure_early_stopping import V1FailureEarlyStopping
from polyaxon_sdk.models.v1_median_stopping_policy import V1MedianStoppingPolicy
from polyaxon_sdk.models.v1_metric_early_stopping import V1MetricEarlyStopping
from polyaxon_sdk.models.v1_truncation_stopping_policy import V1TruncationStoppingPolicy

class V1EarlyStopping(BaseModel):
    """
    V1EarlyStopping
    """
    median: Optional[V1MedianStoppingPolicy] = None
    diff: Optional[V1DiffStoppingPolicy] = None
    truncation: Optional[V1TruncationStoppingPolicy] = None
    metric: Optional[V1MetricEarlyStopping] = None
    failure: Optional[V1FailureEarlyStopping] = None
    __properties = ["median", "diff", "truncation", "metric", "failure"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1EarlyStopping:
        """Create an instance of V1EarlyStopping from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of median
        if self.median:
            _dict['median'] = self.median.to_dict()
        # override the default output from pydantic by calling `to_dict()` of diff
        if self.diff:
            _dict['diff'] = self.diff.to_dict()
        # override the default output from pydantic by calling `to_dict()` of truncation
        if self.truncation:
            _dict['truncation'] = self.truncation.to_dict()
        # override the default output from pydantic by calling `to_dict()` of metric
        if self.metric:
            _dict['metric'] = self.metric.to_dict()
        # override the default output from pydantic by calling `to_dict()` of failure
        if self.failure:
            _dict['failure'] = self.failure.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1EarlyStopping:
        """Create an instance of V1EarlyStopping from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1EarlyStopping.parse_obj(obj)

        _obj = V1EarlyStopping.parse_obj({
            "median": V1MedianStoppingPolicy.from_dict(obj.get("median")) if obj.get("median") is not None else None,
            "diff": V1DiffStoppingPolicy.from_dict(obj.get("diff")) if obj.get("diff") is not None else None,
            "truncation": V1TruncationStoppingPolicy.from_dict(obj.get("truncation")) if obj.get("truncation") is not None else None,
            "metric": V1MetricEarlyStopping.from_dict(obj.get("metric")) if obj.get("metric") is not None else None,
            "failure": V1FailureEarlyStopping.from_dict(obj.get("failure")) if obj.get("failure") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.0-rc19
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class V1RunKind(str, Enum):
    """
    V1RunKind
    """

    """
    allowed enum values
    """
    JOB = 'job'
    SERVICE = 'service'
    DAG = 'dag'
    SPARK = 'spark'
    DASK = 'dask'
    FLINK = 'flink'
    RAY = 'ray'
    MPIJOB = 'mpijob'
    TFJOB = 'tfjob'
    PYTORCHJOB = 'pytorchjob'
    PADDLEJOB = 'paddlejob'
    MXJOB = 'mxjob'
    XGBJOB = 'xgbjob'
    MATRIX = 'matrix'
    SCHEDULE = 'schedule'
    TUNER = 'tuner'
    WATCHDOG = 'watchdog'
    NOTIFIER = 'notifier'
    CLEANER = 'cleaner'
    BUILDER = 'builder'




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.0-rc19
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class SparkDeployMode(str, Enum):
    """
    SparkDeployMode
    """

    """
    allowed enum values
    """
    CLUSTER = 'cluster'
    CLIENT = 'client'
    IN_CLUSTER_CLIENT = 'in_cluster_client'




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.0-rc19
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "polyaxon-sdk"
VERSION = "2.0.0-rc19"
PYTHON_REQUIRES = ">=3.7"
REQUIRES = [
    "urllib3 >= 1.25.3",
    "python-dateutil",
    "pydantic",
    "aenum"
]

setup(
    name=NAME,
    version=VERSION,
    description="Polyaxon SDKs and REST API specification.",
    author="Polyaxon sdk",
    author_email="contact@polyaxon.com",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "Polyaxon SDKs and REST API specification."],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description_content_type='text/markdown',
    long_description="""\
         # noqa: E501
    """
)



# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.0-rc19
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class V1ConnectionKind(str, Enum):
    """
    V1ConnectionKind
    """

    """
    allowed enum values
    """
    HOST_PATH = 'host_path'
    VOLUME_CLAIM = 'volume_claim'
    GCS = 'gcs'
    S3 = 's3'
    WASB = 'wasb'
    REGISTRY = 'registry'
    GIT = 'git'
    AWS = 'aws'
    GCP = 'gcp'
    AZURE = 'azure'
    MYSQL = 'mysql'
    POSTGRES = 'postgres'
    ORACLE = 'oracle'
    VERTICA = 'vertica'
    SQLITE = 'sqlite'
    MSSQL = 'mssql'
    REDIS = 'redis'
    PRESTO = 'presto'
    MONGO = 'mongo'
    CASSANDRA = 'cassandra'
    FTP = 'ftp'
    GRPC = 'grpc'
    HDFS = 'hdfs'
    HTTP = 'http'
    PIG_CLI = 'pig_cli'
    HIVE_CLI = 'hive_cli'
    HIVE_METASTORE = 'hive_metastore'
    HIVE_SERVER2 = 'hive_server2'
    JDBC = 'jdbc'
    JENKINS = 'jenkins'
    SAMBA = 'samba'
    SNOWFLAKE = 'snowflake'
    SSH = 'ssh'
    CLOUDANT = 'cloudant'
    DATABRICKS = 'databricks'
    SEGMENT = 'segment'
    SLACK = 'slack'
    DISCORD = 'discord'
    MATTERMOST = 'mattermost'
    PAGERDUTY = 'pagerduty'
    HIPCHAT = 'hipchat'
    WEBHOOK = 'webhook'
    CUSTOM = 'custom'

